%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This function simulates the noise that is added to the 
%signal at the receiver. The noise is generated by first
%generating a signal that is then attenuated by information
%by factors given in [2]. The value of exno for a certain
%distance d is also gathered from the same source. The 
%function is based on "cp0801_Gnoise2" programmed by
%Guerino Giancola in [1].
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
% Introduces additive white Gaussian noise over signal
% 'input'.
% Vector 'exno' contains the target values of Ex/No (in dB)
% 'numpulses' is the number of pulses composing the input
% signal
% 
% Multiple output signals are generated, one signal for
% each target value of Ex/No. The array 'output' contains
% all the signals (input+AWGN), one signal per row.
% The array 'noise' contains the different realization of 
% the Gaussian noise, one realization per each row.
%
%
%

function [noise] = ...
   cp0801_Gnoise_mod(fc,lengdeoutput)

% -------------------------------
% Step One - Introduction of AWGN
% -------------------------------

fc = 5e9;
dPPM = 0.5e-9;

bits=cp0201_bits(200);
[bits,THcoda,Stxta,Refa]=cp0201_transmitter_2PPM_TH_3(bits,0.5e-9,fc,1,62e-9,-2.5);

d=6;
tx=1;
A0=47;
c0=10^(-A0/20);
gamma=1.7;
[rx,attn]=cp0801_pathloss(tx,c0,d,gamma);
input=Stxta.*attn;
exno=14.9;

numpulses=length(bits);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




Ex = (1/numpulses)*sum(input.^2);  % measured energy per
                                   % pulse
ExNo = 10.^(exno./10);             % Ex/No in linear units     
No = Ex ./ ExNo;                   % Unilateral spectral
                                   % density
nstdv = sqrt(No./2);               % Standard deviation for
                                   % the noise

for j = 1 : length(ExNo)
        
    noise(j,:) = nstdv(j) .* randn(1,length(lengdeoutput));
   
end
