%
% FUNCTION 8.4 : "cp0801_PPMcorrmask"
%
% Evaluates the correlation mask ('mask') in the
% case of binary PPM UWB signals.
% 'ref' is the reference signal (with no modulation)
% which is produced by the 2PPM+TH transmitter
% 'fc' is the sampling frequency
% 'numpulses' is the number of transmitted pulses
% 'dPPM' is the value of the PPM shift
%
% Programmed by Guerino Giancola
%

function [mask] = cp0801_PPMcorrmask(ref,fc,numpulses,dPPM)

% ---------------------------------------------
% Step One - Evaluation of the correlation mask
% ---------------------------------------------

dt = 1 / fc;

% Energy normalization
Epulse = (sum((ref.^2).*dt))/numpulses;
ref = ref./sqrt(Epulse);

% Mask construction
PPMsamples = floor (dPPM ./ dt);
sref(1:PPMsamples)=ref(length(ref)- ...
   PPMsamples+1:length(ref));
sref(PPMsamples+1:length(ref)) = ref(1:length(ref)- ...
   PPMsamples);
mask = ref-sref;
