%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 Channel Model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This function simulates the channel model and the effects it has on 
%the transmitted signal. The simulation is done according to the
%statistical model proposed by IEEE 802.15.SG3a. The channel impulse
%response is generated accordingly and the effects of path loss are also
%taken into account. Calculations are made to consider four different
%scenarios. These are LOS/NLOS for distances d<=4 meters and d>4 meters.
%The parameters are all set according to the assumptions proposed by [1]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [hf, ts2, SRX2] = kanalmodell(d, type, antpulser, fc, Stx)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%d: The distance between transmitter and receiver
%A0: The referance attenuation
%type: 1=LOS(Line of sight) 0=NLOS(Non Line Of Sight)
%antpulser: Number of pulses
%exno: The ratio between the received energy within a single pulse and the noise level(Ex/N0)
%stx: The signal from the transmitter.
%hf: Discrete channel impulse response
%ts2= The time resolution in seconds
%SRX2: The received signal after transmission over the channel
%G: G=1 plots the channel model G=0 no plot.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
G=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculates the channel model based on LOS/NLOS and distance
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%&&&&

if type==0 & d<=4
%NLOS 0-4 meters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Finds the attenuation coefficient based on the distance d
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tx=1;
A0=51;
c0=10^(-A0/20);
gamma=3.5;
[rx,attn]=cp0801_pathloss(tx,c0,d,gamma);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates the channel impulse response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
TMG=attn^2;%Average total multipath gain at distance d
[h0,hf,OT,ts,X] = cp0802_IEEEuwbNLOS4(fc,TMG,G);
ts2=ts;
end
    

if type==0 & d>4
%NLOS 4-10 meters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Finds the attenuation coefficient based on the distance d
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tx=1;
A0=51;
c0=10^(-A0/20);
gamma=3.5;
[rx,attn]=cp0801_pathloss(tx,c0,d,gamma);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates the channel impulse response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
TMG=attn^2;
[h0,hf,OT,ts,X] = cp0802_IEEEuwbNLOS10(fc,TMG,G);
ts2=ts;    
end

if type==1 & d<=4
%LOS 0-4 meters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Finds the attenuation coefficient based on the distance d
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tx=1;
A0=47;
c0=10^(-A0/20);
gamma=1.7;
[rx,attn]=cp0801_pathloss(tx,c0,d,gamma);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates the channel impulse response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
TMG=attn^2;
[h0,hf,OT,ts,X] = cp0802_IEEEuwbLOS4(fc,TMG,G);
 ts2=ts;   
end
    

if type==1 & d>4
%LOS 4-15 meters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Finds the attenuation coefficient based on the distance d
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tx=1;
A0=47;
c0=10^(-A0/20);
gamma=1.7;
[rx,attn]=cp0801_pathloss(tx,c0,d,gamma);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates the channel impulse response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
TMG=attn^2;
[h0,hf,OT,ts,X] = cp0802_IEEEuwbLOS10(fc,TMG,G);
ts2=ts;   
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



SRX = conv(Stx,hf);
SRX2 = SRX(1:length(Stx)); %The signal after transmission over the channel






