%The function simulates the ranging procedure between the reference nodes
%and the target node. Parameters set in this file apply for 'Posisjonering_hovedfil.m' also.
%The file sets up and simulates the communication between the reference
%nodes and the target node (transmitter/receiver communication) while
%taking into account time delays and channel models. Noise is also added at
%the receiver in order to make the simulations more realistic.
%
%Function input: 'distanse' (The real ranges estimated in Posisjonering_hovedfil.m)
%Function output: 'estimert_avstand' (estimated ranges/distances after the signal has been
%                                     subjected to delay and the channel model)
%
function [estimert_avstand] = posisjonering(distanse)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%distanse=[2]
rand('state',sum(100*clock))

Pow=-10;%opprinnelig:-10 The power avaliable
fc =44e9;%opprinnelig:22e9 Sampling frequency of the output signal
dPPM = 0.5e-9;%value of the PPM shift
dt=1/fc;
delta=100e-9; %Delay time before response

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%NODE INFO  [Node(1),Node(2),Node(n)...Node(n+1)]             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for k=1:length(distanse)
    
%distanse=[4.234 4.234];

LOSNLOS = [1 1 1 1 1 1 1 1 1]; %1=LOS(Line of sight) 0=NLOS(Non Line Of Sight)
Ns=[12];%12 fr The nuber of pulses to be produced for each bit 
Ts =[9e-9];%9 fr Pulse repetition period, determines  the position in time of each pulse

sendebits=cp0201_bits(1);%generates a random bit stream


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Transmitter
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for n=1:1;
bits= sendebits;
[bits,THcodes(n,:),Stxtot,Referanse]=cp0201_transmitter_2PPM_TH_2(bits,dPPM,fc,Ns,Ts,Pow);
rate=1/(Ts(n)*Ns(n));
disp(['Node ' num2str(n) ': ' num2str(rate) ' Bit/sec'])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates the delayed signal
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Stx_delay(n,:)=delayed signal
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for n=1:2
delay=distanse(k)/299792458; %time delay of the signal based on the speed of light
g=length(Stxtot);
xg=3*g;
pilot(n,:)=zeros(1,xg);
pilot(n,1:g)=Stxtot;
[Stx_delay(n,:)]=cp0804_signalshift(pilot(n,:),fc,delay);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates channel model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%hf{n}=discrete channel model
%SRXHF{n}=attenuated and delayed signal at the receiver
%tstemp(n)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('- Channel model for the different nodes based on distance and LOS/NLOS!')
clear n;
for n=1:2;
%disp('- Wait.......')
antpulser=Ns*length(sendebits);
[hf{n}, tstemp(n), SRXHF{n}] = kanalmodell2(distanse(k), LOSNLOS(k), antpulser, fc, Stx_delay(n,:));
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates correlator mask for rake receiver
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for n=1:2;
[G,T,NF,Arake{n},Srake{n},Prake{n}] = cp0803_rakeselector(hf{n},fc,tstemp(n),5,5);

tempconv=conv(Srake{n},pilot(n,:));
pilot_Srake(n,:)=tempconv(1:length(pilot(n,:)));
clear tempconv;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Detection and distance estimation at the receiver
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for n=1:2;
%s=randn(1,length(SRXHF{n}))% Generates -83 dBm = 5.0119e-12 AWGN thermal noise at the receiver
%s2=(s*2)-1                %
%stoy=s2*0.000002239%5.0119e-12     %
stoy=cp0801_Gnoise_mod(fc,SRXHF{n}); %Thermal noise at the receiver. The function is cp0801_Gnoise2.m modified

Rx_delay_stoy(n,:)=sumarray(SRXHF{n},stoy); %received signal at the receiver with noise included
%[Stxdelay_stoy,noise]=cp0801_Gnoise2(Stx_delay(n,:),-1,antpulser);

[Korrelert_signal_kanal(n,:)]=cp0804_corrsyn(Rx_delay_stoy(n,:),pilot_Srake(n,:),fc); %Correlation between the signal at the
                                                                                      %receiver input(the delayed noise-affected signal) and
                                                                                      %the Srake receiver.

%[Korrelert_signal(n,:)]=cp0804_corrsyn(Stxdelay_stoy,pilot(n,:),fc);



[peak,index]=max(Korrelert_signal_kanal(n,:));
estimated_delay1(n)=index*dt %estimated delay for received signal at the point where the signal
                             %is at its strongest, in order to get a best
                             %possible reading.

%[peak,index]=max(Korrelert_signal(n,:));
%estimated_delay2(n)=index*dt %estimert forsinkelse for test signal

%tid=linspace(0,(dt*length(Korrelert_signal_kanal(n,:))),length(Korrelert_signal_kanal(n,:)));
%figure;
%plot(tid,Korrelert_signal_kanal(n,:))
%figure;
%plot(tid,Korrelert_signal(n,:))

end
%%%%%%%%%Ranging procedure accordin to the theory%%%%%%%%%%%%%%%%%%%%
t0=1;
t1=t0+estimated_delay1(1)+estimated_delay1(2)+delta %the time when the reference node receives the response package
estimert_forsinkelse(k)=(t1-t0-delta)/2
estimert_avstand(k)=estimert_forsinkelse(k)*299792458 %calculating the distance d between two nodes by multiplying the
                                                      %estimated delay with the speed of light.


end



